@@ -194,7 +194,7 @@ impl TryFrom<protocol::Package> for Msg{
                         }
                     }
                     _ => {
-                        println!("unknown msg str key");
+                        //println!("unknown msg str key");
                         Err(())
                     }
                 }
@@ -226,20 +226,20 @@ impl TryFrom<Vec<u8>> for structs::TinkoffApiKey{
             str_ends = nom+8;
             if *char == 0{ break }
         }
-        match String::from_utf8(bytes[5..str_ends].to_owned()){
+        match String::from_utf8(bytes[8..str_ends].to_owned()){
             Ok(name) => {
                 match String::from_utf8(bytes[str_ends+1..].to_vec()){
                     Ok(key) => {
                         Ok(Self{name, key, time})
                     }
                     Err(_) => {
-                        println!("cant parse key");
+                        //println!("cant parse key");
                         Err(())
                     }
                 }
             }
             Err(_) => {
-                println!("cant parse name");
+                //println!("cant parse name");
                 Err(())
             }        }
     }
